#
# Copyright (C) 2020 Arm Mbed. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
#
"""The version number is based on semantic versioning.

References
- https://semver.org/
- https://www.python.org/dev/peps/pep-0440/

This file is autogenerated, do not modify by hand.
"""
__version__ = "2.0.0-beta.22"
COMMIT = "aec360c5529e8f705b5ff0a3a359ef7053a66fec"
MAJOR = 2
MINOR = 0
PATCH = 0
